import {MapPinIcon, MoveRightIcon} from "lucide-react";
import {notNil} from "../../utils";
import {Job} from "../type";
import {FC} from "react";

type JobsProps = {
	jobs: Job[] | undefined
}

export const Jobs: FC<JobsProps> = ({jobs}) => {
	return (
		<>
			<section className="px-4">
				<ol className="relative border-s border-gray-200 dark:border-gray-700">
					{jobs?.filter(notNil).map(({name, started, ended, description, tags, link}, index) => (
						<li key={index} className="mb-10 ms-6">
							<span
								className="absolute flex items-center justify-center w-6 h-6 bg-white rounded-full -start-3 ring-8 ring-white dark:ring-slate-800 dark:bg-slate-800">
								<MapPinIcon className="text-black dark:text-white"/>
							</span>
							<h3 className="flex items-center gap-2 mb-1 text-lg font-semibold text-gray-900 dark:text-white">
								{name}
							</h3>
							<time className="block mb-2 text-sm font-normal leading-none text-gray-400 dark:text-gray-500">
								{started} - {ended}
							</time>
							<p className="mb-4 text-base font-normal text-gray-500 dark:text-gray-400">
								{description}
							</p>
							{link != undefined &&
								<p>
									<a href={link}
										 target="_blank"
										 className="inline-flex gap-2 mb-4 items-center px-4 py-2 text-sm font-medium text-gray-900 bg-white border border-gray-200 rounded-lg hover:bg-gray-100 hover:text-blue-700 dark:bg-gray-800 dark:text-gray-400 dark:border-gray-600 dark:hover:text-white dark:hover:bg-gray-700">
										Visit website
										<MoveRightIcon/>
									</a>
								</p>
							}
							<p className="flex flex-wrap gap-2">
								{tags.sort().map((name) => (
									<span
										key={name}
										className="bg-purple-100 text-purple-800 text-xs font-medium me-2 px-2.5 py-0.5 rounded-full dark:bg-purple-900 dark:text-purple-300"
									>
										{name}
									</span>
								))}
							</p>
						</li>
					))}
				</ol>
			</section>
		</>
	)
}